@@ -38,6 +38,8 @@ class Template extends xmlTemplate {
 	private $invalid_reason;
 	# The TEMPLATE structural objectclasses
 	protected $structural_oclass = array();
+	# The objectclasses for which this template is the default
+	protected $defaultfor_oclass = array();
 	protected $description = '';
 	# Is this a read-only template (only valid in modification templates)
 	private $readonly = false;
@@ -125,6 +127,31 @@ class Template extends xmlTemplate {
 
 					break;
 
+				# Record our defaultFor object Classes from the Template.
+				case ('defaultforobjectclasses'):
+					if (DEBUG_ENABLED)
+						debug_log('Case [%s]',4,0,__FILE__,__LINE__,__METHOD__,$xml_key);
+
+					if (isset($xmldata['template'][$xml_key]['defaultforobjectclass']))
+						if (is_array($xmldata['template'][$xml_key]['defaultforobjectclass'])) {
+							foreach ($xmldata['template'][$xml_key]['defaultforobjectclass'] as $index => $details) {
+
+								# If we havent recorded this objectclass already, do so now.
+								if (! in_array($details,$this->defaultfor_oclass))
+									array_push($this->defaultfor_oclass,$details);
+							}
+
+						} else {
+							# XML files with only 1 objectClass dont have a numeric index.
+							$soc = $xmldata['template'][$xml_key]['defaultforobjectclass'];
+
+							# If we havent recorded this objectclass already, do so now.
+							if (! in_array($soc,$this->defaultfor_oclass))
+								array_push($this->defaultfor_oclass,$soc);
+						}
+
+					break;
+
 				# Build our attribute list from the DN and Template.
 				case ('attributes'):
 					if (DEBUG_ENABLED)
@@ -180,6 +207,7 @@ class Template extends xmlTemplate {
 
 					if ($xml_key == 'invalid' && $xml_value)
 						$this->setInvalid(_('Disabled by XML configuration'),true);
+
 			}
 		}
 
@@ -633,6 +661,8 @@ class Template extends xmlTemplate {
 		# If container is not set, we're probably creating the base
 		elseif ($this->getRDN() && get_request('create_base'))
 			return $this->getRDN();
+
+		return '';
 	}
 
 	public function getDNEncode($url=true) {
@@ -925,6 +955,15 @@ class Template extends xmlTemplate {
 		$this->visible = false;
 	}
 
+	/**
+	 * Get the objectclasses for which this template is the default
+	 *
+	 * @return array The objectclasses
+	 */
+	public function getDefaultForObjectClass() {
+		return $this->defaultfor_oclass;
+	}
+
 	public function getRegExp() {
 		if (DEBUG_ENABLED && (($fargs=func_get_args())||$fargs='NOARGS'))
 			debug_log('Entered (%%)',5,1,__FILE__,__LINE__,__METHOD__,$fargs,$this->regexp);
