@@ -176,7 +176,9 @@ class ImportLDIF extends Import {
 					return $this->error(sprintf('%s %s',_('LDIF import only suppports version 1'),$version),$lines);
 
 				$haveVersion = true;
-				$lines = $this->nextLines();
+
+				if (! $lines)
+					$lines = $this->nextLines();
 			}
 
 			$server = $this->getServer();
@@ -542,7 +544,7 @@ class ImportLDIF extends Import {
 						array_merge(array($currentLine),$lines));
 
 				$currentLine = array_shift($lines);
-				if (trim($currentLine))
+				if (is_string($currentLine) && trim($currentLine) !== '')
 					$processline = true;
 			}
 
